@@ -66,12 +66,12 @@ sub add_ad_groups {
     new({create => $ad_group});
 
   # Add the ad group.
-  my $ad_group_response = $api_client->AdGroupService()->mutate({
+  my $ad_groups_response = $api_client->AdGroupService()->mutate({
       customerId => $customer_id,
       operations => [$ad_group_operation]});
 
   printf "Created ad group '%s'.\n",
-    $ad_group_response->{results}[0]{resourceName};
+    $ad_groups_response->{results}[0]{resourceName};
 
   return 1;
 }
