@@ -48,6 +48,7 @@ my $feed_item_id = "INSERT_FEED_ITEM_ID_HERE";
 # https://developers.google.com/adwords/api/docs/appendix/geotargeting
 my $geo_target_constant_id = 2840;    # US
 
+# [START add_geo_target]
 sub add_geo_target {
   my ($api_client, $customer_id, $feed_item_id, $geo_target_constant_id) = @_;
 
@@ -73,18 +74,20 @@ sub add_geo_target {
       updateMask => all_set_fields_of($extension_feed_item)});
 
   # Issue a mutate request to update the extension feed item.
-  my $extension_feed_item_response =
+  my $extension_feed_items_response =
     $api_client->ExtensionFeedItemService()->mutate({
       customerId => $customer_id,
       operations => [$extension_feed_item_operation]});
 
   # Print the resource name of the updated extension feed item.
-  my $updated_extension_feed_item = $extension_feed_item_response->{results}[0];
+  my $updated_extension_feed_item =
+    $extension_feed_items_response->{results}[0];
   printf "Updated extension feed item with resource name: '%s'.\n",
     $updated_extension_feed_item->{resourceName};
 
   return 1;
 }
+# [END add_geo_target]
 
 # Don't run the example if the file is being included.
 if (abs_path($0) ne abs_path(__FILE__)) {
